import { render } from '@testing-library/react';

import RootLayout, { metadata } from '../layout';

// Mock next/font/google since it's not available in the test environment
jest.mock('next/font/google', () => ({
  Geist: () => ({
    variable: '--font-geist-sans',
  }),
  Geist_Mono: () => ({
    variable: '--font-geist-mono',
  }),
}));

// Mock globals.css import
jest.mock('../globals.css', () => ({}));

describe('RootLayout', () => {
  it('renders children correctly', () => {
    const testContent = <div data-testid="test-content">Test content</div>;
    const { getByTestId } = render(<RootLayout>{testContent}</RootLayout>);

    expect(getByTestId('test-content')).toBeInTheDocument();
    expect(getByTestId('test-content')).toHaveTextContent('Test content');
  });

  it('creates proper HTML structure with lang attribute', () => {
    const testContent = <div>Test</div>;
    const { container } = render(<RootLayout>{testContent}</RootLayout>);
    
    // The component returns JSX with html and body elements
    // We can test that the component renders without errors
    expect(container.firstChild).toBeInTheDocument();
  });

  it('has correct metadata export', () => {
    expect(metadata).toBeDefined();
    expect(metadata.title).toBe('Create Next App');
    expect(metadata.description).toBe('Generated by create next app');
  });

  it('applies font classes correctly', () => {
    // Test that the component can be instantiated and called
    const testContent = <div>Test</div>;
    const renderResult = render(<RootLayout>{testContent}</RootLayout>);
    
    // Just ensure it renders without throwing errors
    expect(renderResult.container).toBeInTheDocument();
  });
}); 